@@ -376,7 +376,7 @@ class ListDirCache(object):
     def key(self, index):
         """Returns a key for a user distributed cache."""
         logging.debug("cache key for %r" % [self.cffs.authurl, self.cffs.username, index])
-        if not hasattr(self, "_key_base"):
+        if not hasattr(self, "_key_base") and self.cffs.username:
             self._key_base = md5("%s%s" % (self.cffs.authurl, self.cffs.username)).hexdigest()
         return "%s-%s" % (self._key_base, md5(smart_str(index)).hexdigest())
 
@@ -591,12 +591,11 @@ class ObjectStorageFS(object):
         """
         Create the Object Storage connection.
 
-        username - if None then don't make the connection
+        username - if None then don't make the connection (delayed auth)
         api_key
         authurl
         keystone - optional for auth 2.0 (keystone)
         """
-        self.username = username
         self.conn = None
         self.authurl = authurl
         self.keystone = keystone
@@ -638,6 +637,8 @@ class ObjectStorageFS(object):
         # force authentication
         self.conn.url, self.conn.token = self.conn.get_auth()
         self.conn.http_conn = None
+        # now we are authenticated and we have an username
+        self.username = username
 
     def close(self):
         """Dummy function which does nothing - no need to close"""
